mod bool;
mod chars;
mod dice;
mod float;
mod integer;
#[cfg(feature = "uuid_crate")]
mod uuid;
